<table class="table">
    <thead>
        <tr>
            <th>Legislation Type</th>
            <th>Description</th>
        </tr>
    </thead>
    <tbody>
    {% for leg_type in LEGISLATION_TYPE_DESCRIPTIONS %}
        <tr>
            <td>
                <i class="fa fa-fw fa-{{leg_type.fa_icon}}"></i>
                <a href="/search/?q=&selected_facets=bill_type_exact:{{leg_type.search_term}}">
                    {{leg_type.name}}
                </a>
            </td>
            <td>
                {% if leg_type.html_desc %}
                    <p>{{leg_type.desc|safe}}</p>
                {% else %}
                    <p>{{leg_type.desc}}</p>
                {% endif %}
            </td>
        </tr>
    {% endfor %}
    </tbody>
</table>

