{% extends "base.html" %}
{% block title %}Page not found{% endblock %}
{% block content %}

    <div class="row-fluid">
        <div class="col-sm-12">
            <h1>Page Not Found</h1>
            <p>What you were looking for is just not there.</p>
            <p><a href="/">&laquo; go back to the home page</a></p>
        </div>
    </div>

{% endblock %}