{% extends "base_with_margins.html" %}
{% block title %}About{% endblock %}
{% block content %}

    <div class="row-fluid clearfix">
        <div class="col-sm-8 no-pad-mobile">
            <br />
            <h1 id='about'>About</h1>

            <p><strong>{{ CITY_NAME_SHORT }} Councilmatic</strong> is a tool for understanding and tracking what’s happening in {{ CITY_COUNCIL_NAME }}.</p>
            <p>This site connects {{ CITY_NAME_SHORT }} residents to local city council offices, for greater online public dialogue about issues in their communities.</p>

            <p>Councilmatic helps you:</p>
            <ul>
                <li>
                    Keep up with what your local representatives is up to
                </li>
                <li>
                    See the schedule of public events
                </li>
                <li>
                    Track and comment on issues you care about
                </li>
            </ul>


        </div>
        <div class="col-sm-4 desktop-only">
            <br/>
            <br>
            <div class="well well-sm">
                <h4>Contents</h4>
            </div>
        </div>
    </div>
    <div class="row-fluid">
        <div class="col-sm-8 no-pad-mobile" id="about-city-council">

            <p>Below are the primary types of city council activity.</p>
        
            {% include 'partials/component_bill_type_table.html' %}

        </div>
    </div>


{% endblock %}
