{% load extras %}
<p class="small text-muted no-pad-bottom">
    <span class="text-muted"><i class="fa fa-fw fa-check"></i> Passed on {{legislation.date_passed|date:'n/d'}}</span><br />
    <a href="/legislation/{{ legislation.slug }}">{{ legislation.friendly_name }}</a>
</p>
<div class='row'>
    <div class='col-xs-11'>
        <p>
            {{ legislation.listing_description | short_blurb }}.
        </p>

    </div>
    <div class='col-xs-1 no-pad-mobile'>
        <div>
            <a class='btn-bill-detail' href='/legislation/{{ legislation.slug }}'>
                <i class="fa fa-fw fa-chevron-right"></i>
            </a>
        </div>
    </div>
</div>
<p>
    <i class="fa fa-fw fa-tag"></i>
    {% for c in legislation.committees_involved %}
        <span class="badge badge-muted pseudo-topic-tag">
            {{ c | committee_topic_only }}
        </span>&nbsp;
    {% endfor %}
    <br/><br/>
</p>